import { Tab } from "@headlessui/react";
import React, { useEffect, useRef, useState } from "react";
import { useUserOrderListQuery } from "../../app/features/userDashboard/apiSlice";
import EmptyWishList from "./EmptyWishList";
import Link from "next/link";
import useLanguage from "../../hooks/useLanguage";

function OrderList() {
  const [page, setPage] = useState(1);
  const { data, error, isLoading, isFetching } = useUserOrderListQuery(page);
  const observerTarget = useRef(null);

  useEffect(() => {
    const observer = new IntersectionObserver(
      (entries) => {
        if (entries[0].isIntersecting) {
          if (!isFetching && data?.orders?.total > data?.orders?.to) {
            setPage((prev) => prev + 1);
          }
        }
      },
      { threshold: 1 }
    );

    if (observerTarget.current) {
      observer.observe(observerTarget.current);
    }

    return () => {
      if (observerTarget.current) {
        observer.unobserve(observerTarget.current);
      }
    };
  }, [observerTarget, isFetching, data?.orders]);
  const language = useLanguage();
  return (
    <>
      <Tab.Panel>
        <h3 className="text-2xl text-dark-300 font-bold mb-4 notranslate">
          {language["My Order"]}
        </h3>
        <div className="w-full  border border-primary-100 rounded-md p-5 ">
          <ul className="divide-y divide-primary-100">
            {data?.orders?.data?.length > 0 ? (
              data?.orders?.data?.map((order) => (
                <li
                  key={order.id}
                  className="pr-4 py-3 whitespace-nowrap flex flex-col md:flex-row justify-between gap-5"
                >
                  <div className="flex justify-between flex-1">
                    <div className="px-4 py-3 whitespace-nowrap">
                      <h4 className="text-dark-300 font-bold text-lg notranslate">
                        {language["Order ID"]}:
                      </h4>
                      <p className="text-dark-200 text-sm">{order.order_id}</p>
                    </div>
                    <div className="px-4 py-3 whitespace-nowrap">
                      <p className="text-primary-200 text-sm">Ton</p>
                      <h4 className="font-bold text-2xl">
                        {order.product_qty}
                      </h4>
                    </div>
                    <div className="px-4 py-3 whitespace-nowrap">
                      <p className="text-primary-200 text-sm">Price</p>
                      <h4>${order.total_amount}</h4>
                    </div>
                  </div>
                  <div className="px-4 py-3 whitespace-nowrap">
                    <Link href={`/user-dashboard/${order.order_id}`} passHref>
                      <a className="py-3.5 px-7 text-lg font-medium rounded-md bg-dark-300 text-white transition hover:text-dark-300 hover:bg-secondary notranslate">
                        {language["View Details"]}
                      </a>
                    </Link>
                  </div>
                </li>
              ))
            ) : (
              <EmptyWishList />
            )}
          </ul>{" "}
        </div>
        {isFetching ? "Loading...." : ""}
      </Tab.Panel>

      <div ref={observerTarget}></div>
    </>
  );
}

export default OrderList;
